<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Tester si un binaire est présent
 * 
 * @param string $command_name
 * @return bool
 */
function optimages_command_exists($command_name) {
   $test_method = (false === stripos(PHP_OS, 'win')) ? 'command -v' : 'where';
   return (null === shell_exec("$test_method $command_name")) ? false : true;
}

/**
 * Définition des saisies pour générer le formulaire de configuration
 *
 * @return array<mixed> $saisies
 */
function formulaires_configurer_optimages_saisies_dist(): array {
	$saisies = [
		[
			'saisie' => 'case',
			'options' => [
				'nom' => 'sauvegarde',
				'label_case' => '<:optimages:configurer_sauvegarde_label_case:>',
				'conteneur_class' => 'pleine_largeur'
			]
		],
		[
			'saisie' => 'fieldset',
			'options' => [
				'nom' => 'optimizers',
				'label' => '<:optimages:configurer_optimizers_label:>',
			],
			'saisies' => [
				// JPEG
				[
					'saisie' => 'fieldset',
					'options' => [
						'nom' => 'jpegoptim',
						'label' => '<:optimages:configurer_jpegoptim_label:>',
					],
					'saisies' => [
						[
							'saisie' => 'case',
							'options' => [
								'nom' => 'jpegoptim_activer',
								'label_case' => '<:optimages:configurer_jpegoptim_activer_label_case:>'
							]
						],
						[
							'saisie' => 'input',
							'options' => [
								'nom' => 'jpegoptim_options',
								'label' => '<:optimages:configurer_jpegoptim_options_label:>',
								'explication' => '<:optimages:configurer_jpegoptim_options_explication:>',
								'afficher_si' => '@jpegoptim_activer@=="on"',
								'defaut' => '\'-m85\', \'--strip-all\', \'--all-progressive\'',
							]
						],
					]
				],
				// PNG
				[
					'saisie' => 'fieldset',
					'options' => [
						'nom' => 'png',
						'label' => '<:optimages:configurer_png_label:>',
						'attention' => '<:optimages:configurer_png_attention:>',
						'explication' => '<:optimages:configurer_png_explication:>',

					],
					'saisies' => [
						[
							'saisie' => 'case',
							'options' => [
								'nom' => 'pngquant_activer',
								'label_case' => '<:optimages:configurer_pngquant_activer_label_case:>'
							]
						],
						[
							'saisie' => 'input',
							'options' => [
								'nom' => 'pngquant_options',
								'label' => '<:optimages:configurer_pngquant_options_label:>',
								'explication' => '<:optimages:configurer_pngquant_options_explication:>',
								'afficher_si' => '@pngquant_activer@=="on"',
								'defaut' => '\'--quality=85\',\'--force\',\'--skip-if-larger\'',
							]
						],
						[
							'saisie' => 'case',
							'options' => [
								'nom' => 'optipng_activer',
								'label_case' => '<:optimages:configurer_optipng_activer_label_case:>'
							]
						],
						[
							'saisie' => 'input',
							'options' => [
								'nom' => 'optipng_options',
								'label' => '<:optimages:configurer_optipng_options_label:>',
								'explication' => '<:optimages:configurer_optipng_options_explication:>',
								'afficher_si' => '@optipng_activer@=="on"',
								'defaut' => '\'-i0\', \'-o2\'',
							]
						],
					]
				],
				// GIF
				[
					'saisie' => 'fieldset',
					'options' => [
						'nom' => 'gifsicle',
						'label' => '<:optimages:configurer_gifsicle_label:>',
						'attention' => '<:optimages:configurer_gifsicle_attention:>',
					],
					'saisies' => [
						[
							'saisie' => 'case',
							'options' => [
								'nom' => 'gifsicle_activer',
								'label_case' => '<:optimages:configurer_gifsicle_activer_label_case:>'
							]
						],
						[
							'saisie' => 'input',
							'options' => [
								'nom' => 'gifsicle_options',
								'label' => '<:optimages:configurer_gifsicle_options_label:>',
								'explication' => '<:optimages:configurer_gifsicle_options_explication:>',
								'afficher_si' => '@gifsicle_activer@=="on"',
								'defaut' => '\'-b\', \'-O3\'',
							]
						],
					]
				],
			]
		]
	];

	// Affichage conditionné à la présence de jpegoptim
	if (optimages_command_exists('jpegoptim')) {
		$saisies[1]['saisies'][0]['options']['attention'] = '<:optimages:configurer_jpegoptim_attention:>';
	}
	else {
		$saisies[1]['saisies'][0]['options']['attention'] = '<:optimages:configurer_jpegoptim_attention_absent:>';
		$saisies[1]['saisies'][0]['saisies'][0]['options']['disable'] = 'true';
	}

	// Affichage conditionné à la présence de pngquant
	if (optimages_command_exists('pngquant')) {
		$saisies[1]['saisies'][1]['saisies'][0]['options']['attention'] = '<:optimages:configurer_pngquant_attention:>';
	}
	else {
		$saisies[1]['saisies'][1]['saisies'][0]['options']['attention'] = '<:optimages:configurer_pngquant_attention_absent:>';
		$saisies[1]['saisies'][1]['saisies'][0]['options']['disable'] = 'true';
	}

	// Affichage conditionné à la présence de optipng
	if (optimages_command_exists('optipng')) {
		$saisies[1]['saisies'][1]['saisies'][2]['options']['attention'] = '<:optimages:configurer_optipng_attention:>';
	}
	else {
		$saisies[1]['saisies'][1]['saisies'][2]['options']['attention'] = '<:optimages:configurer_optipng_attention_absent:>';
		$saisies[1]['saisies'][1]['saisies'][2]['options']['disable'] = 'true';
	}

	// Affichage conditionné à la présence de gifsicle
	if (optimages_command_exists('gifsicle')) {
		$saisies[1]['saisies'][2]['options']['attention'] = '<:optimages:configurer_gifsicle_attention:>';
	}
	else {
		$saisies[1]['saisies'][2]['options']['attention'] = '<:optimages:configurer_gifsicle_attention_absent:>';
		$saisies[1]['saisies'][2]['saisies'][0]['options']['disable'] = 'true';
	}

	return $saisies;
}
